JsDoc Reference - links.Point3d

Class Index | File Index

## Classes

- _global_
- links.Filter
- links.Graph3d
- links.Graph3d.Camera
- links.Point2d
- links.Point3d
- links.Slider
- links.StepNumber

# Class links.Point3d

Point3d
Defined in: graph3d.js.

Class Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| links.Point3d(x, y, z)

Method Summary
Method Attributes | Method Name and Description
--- | ---
<static> | links.Point3d.add(a, b) Add the two provided points, returns a+b
<static> | links.Point3d.crossProduct(a, b) Calculate the cross producto of the two provided points, returns axb Documentation: http://en.wikipedia.org/wiki/Cross_product
| length() Rtrieve the length of the vector (or the distance from this point to the origin
<static> | links.Point3d.subtract(a, b) Subtract the two provided points, returns a-b

Class Detail
links.Point3d(x, y, z)

Parameters:
x
y
z

Method Detail
<static> {Point3d} links.Point3d.add(a, b)
Add the two provided points, returns a+b

Parameters:
{Point3d} a
{Point3d} b

Returns:
  {Point3d} a+b

<static> {Point3d} links.Point3d.crossProduct(a, b)
Calculate the cross producto of the two provided points, returns axb Documentation: http://en.wikipedia.org/wiki/Cross_product

Parameters:
{Point3d} a
{Point3d} b

Returns:
  {Point3d} cross product axb

{number} length()
Rtrieve the length of the vector (or the distance from this point to the origin

Returns:
  {number} length

<static> {Point3d} links.Point3d.subtract(a, b)
Subtract the two provided points, returns a-b

Parameters:
{Point3d} a
{Point3d} b

Returns:
  {Point3d} a-b

Documentation generated by JsDoc Toolkit 2.3.2 on Thu May 03 2012 16:42:48 GMT+0200 (CEST)